Package: SIBER
Type: Package
Title: Stable Isotope Bayesian Ellipses in R
Version: 2.1.10
Authors@R: c(
    person("Andrew", "Jackson", role = c("aut", "cre"), 
    email = "jacksoan@tcd.ie",
    comment = c(ORCID = "0000-0001-7334-0434")),
    person("Andrew", "Parnell", role = "aut", 
    comment = c(ORCID = "0000-0001-7956-7939"))
    )
Depends: R (>= 4.0.0)
SystemRequirements: JAGS (>= 4.1)
Imports: hdrcde, graphics, grDevices, mnormt, rjags, spatstat.utils,
        stats, tidyr, dplyr, magrittr
Suggests: coda, ellipse, ggplot2, knitr, purrr, rmarkdown, viridis
Description: Fits bi-variate ellipses to stable isotope data using Bayesian
    inference with the aim being to describe and compare their isotopic
    niche.
License: GPL (>= 2)
Language: en-GB
LazyLoad: yes
LazyData: true
Encoding: UTF-8
Packaged: 2026-02-09 13:30:33 UTC; andrew
NeedsCompilation: yes
VignetteBuilder: knitr
RoxygenNote: 7.3.3
Author: Andrew Jackson [aut, cre] (ORCID:
    <https://orcid.org/0000-0001-7334-0434>),
  Andrew Parnell [aut] (ORCID: <https://orcid.org/0000-0001-7956-7939>)
Maintainer: Andrew Jackson <jacksoan@tcd.ie>
Repository: CRAN
Date/Publication: 2026-02-09 14:20:02 UTC
Built: R 4.6.0; ; 2026-04-26 20:06:38 UTC; unix
