# Generated by roxygen2: do not edit by hand

export(addEllipse)
export(allCentroidVectors)
export(bayesianLayman)
export(bayesianOverlap)
export(communityMetricsML)
export(createSiberObject)
export(ellipseInOut)
export(ellipsoidTransform)
export(extractPosteriorMeans)
export(fitEllipse)
export(generateSiberCommunity)
export(generateSiberData)
export(generateSiberGroup)
export(groupMetricsML)
export(laymanMetrics)
export(maxLikOverlap)
export(plotCommunityHulls)
export(plotGroupEllipses)
export(plotGroupHulls)
export(plotSiberObject)
export(pointsToEllipsoid)
export(posteriorSEA)
export(siberCentroids)
export(siberConvexhull)
export(siberDensityPlot)
export(siberEllipses)
export(siberMVN)
export(sigmaSEA)
export(specificCentroidVectors)
importFrom(magrittr,"%>%")
